@@ -7,9 +7,9 @@ declare -a NEW_PATH_HD_REPAIR_1=(" New path(es) detected" "NewMatchPathDetector:
 declare -a UNPARSED_ATOM_1=(" Unparsed atom received" "SimpleUnparsedAtomHandler: \"UnparsedHandler\" (1 lines)" " System rebooted for hard disk upgrad")
 declare -a UNPARSED_ATOM_2=(" Unparsed atom received" "SimpleUnparsedAtomHandler: \"UnparsedHandler\" (1 lines)" ": System rebooted for hard disk upgrade")
 declare -a NEW_PATH_HOME_PATH_ROOT_1=(" New path(es) detected" "NewMatchPathDetector: \"NewPath\" (1 lines)" "  /model/HomePath: The Path of the home directory shown by pwd of the user root is: /root" "  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user " "  /model/HomePath/Username: root" "  /model/HomePath/Is:  is: " "  /model/HomePath/Path: /root" "['/model/HomePath', '/model/HomePath/Pwd', '/model/HomePath/Username', '/model/HomePath/Is', '/model/HomePath/Path']" "Original log line: The Path of the home directory shown by pwd of the user root is: /root")
-declare -a NEW_VALUE_COMBINATION_HOME_PATH_ROOT_1=(" New value combination(s) detected" "NewMatchPathValueComboDetector: \"NewValueCombo\" (1 lines)" "  /model/HomePath: The Path of the home directory shown by pwd of the user root is: /root" "  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user " "  /model/HomePath/Username: root" "  /model/HomePath/Is:  is: " "  /model/HomePath/Path: /root" "(b'root', b'/root')" "Original log line: The Path of the home directory shown by pwd of the user root is: /root")
-declare -a NEW_VALUE_COMBINATION_HOME_PATH_USER_1=(" New value combination(s) detected" "NewMatchPathValueComboDetector: \"NewValueCombo\" (1 lines)" "  /model/HomePath: The Path of the home directory shown by pwd of the user user is: /home/user" "  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user " "  /model/HomePath/Username: user" "  /model/HomePath/Is:  is: " "  /model/HomePath/Path: /home/user" "(b'user', b'/home/user')" "Original log line: The Path of the home directory shown by pwd of the user user is: /home/user")
-declare -a NEW_VALUE_COMBINATION_HOME_PATH_GUEST_1=(" New value combination(s) detected" "NewMatchPathValueComboDetector: \"NewValueCombo\" (1 lines)" "  /model/HomePath: The Path of the home directory shown by pwd of the user guest is: /home/guest" "  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user " "  /model/HomePath/Username: guest" "  /model/HomePath/Is:  is: " "  /model/HomePath/Path: /home/guest" "(b'guest', b'/home/guest')" "Original log line: The Path of the home directory shown by pwd of the user guest is: /home/guest")
+declare -a NEW_VALUE_COMBINATION_HOME_PATH_ROOT_1=(" New value combination(s) detected" "NewMatchPathValueComboDetector: \"NewValueCombo\" (1 lines)" "(b'root', b'/root')" "Original log line: The Path of the home directory shown by pwd of the user root is: /root")
+declare -a NEW_VALUE_COMBINATION_HOME_PATH_USER_1=(" New value combination(s) detected" "NewMatchPathValueComboDetector: \"NewValueCombo\" (1 lines)" "(b'user', b'/home/user')" "Original log line: The Path of the home directory shown by pwd of the user user is: /home/user")
+declare -a NEW_VALUE_COMBINATION_HOME_PATH_GUEST_1=(" New value combination(s) detected" "NewMatchPathValueComboDetector: \"NewValueCombo\" (1 lines)" "(b'guest', b'/home/guest')" "Original log line: The Path of the home directory shown by pwd of the user guest is: /home/guest")
 declare -a JSON_OUTPUT=()
 read -r -d '' VAR << END
   {
@@ -57,24 +57,7 @@ read -r -d '' VAR << END
       "/model/DiskUpgrade/UNameSpace2",
       "/model/DiskUpgrade/User",
       "/model/DiskUpgrade/HDRepair"
-    ],
-    "ParsedLogAtom": {
-      "/model/DiskUpgrade": "
-END
-JSON_OUTPUT+=("$VAR")
-read -r -d '' VAR << END
- localhost root: System rebooted for hard disk upgrade",
-      "/model/DiskUpgrade/DTM":
-END
-JSON_OUTPUT+=("$VAR")
-read -r -d '' VAR << END
-,
-      "/model/DiskUpgrade/UNameSpace1": " ",
-      "/model/DiskUpgrade/UName": "localhost",
-      "/model/DiskUpgrade/UNameSpace2": " ",
-      "/model/DiskUpgrade/User": "root:",
-      "/model/DiskUpgrade/HDRepair": " System rebooted for hard disk upgrade"
-    }
+    ]
   },
   "LogData": {
     "RawLogData": [
@@ -95,15 +78,22 @@ JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
 ,
     "LogLinesCount": 1,
-    "AnnotatedMatchElement": "/model/DiskUpgrade: 
+    "AnnotatedMatchElement": {
+      "/model/DiskUpgrade": "
 END
 JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
- localhost root: System rebooted for hard disk upgrade\n  /model/DiskUpgrade/DTM:
+",
+      "/model/DiskUpgrade/DTM": "
 END
 JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
-\n  /model/DiskUpgrade/UNameSpace1:  \n  /model/DiskUpgrade/UName: localhost\n  /model/DiskUpgrade/UNameSpace2:  \n  /model/DiskUpgrade/User: root:\n  /model/DiskUpgrade/HDRepair:  System rebooted for hard disk upgrade"
+      "/model/DiskUpgrade/UNameSpace1": " ",
+      "/model/DiskUpgrade/UName": "localhost",
+      "/model/DiskUpgrade/UNameSpace2": " ",
+      "/model/DiskUpgrade/User": "root:",
+      "/model/DiskUpgrade/HDRepair": " System rebooted for hard disk upgrade"
+    }
   }
 }
 {
@@ -178,14 +168,7 @@ read -r -d '' VAR << END
       "/model/HomePath/Username",
       "/model/HomePath/Is",
       "/model/HomePath/Path"
-    ],
-    "ParsedLogAtom": {
-      "/model/HomePath": "The Path of the home directory shown by pwd of the user root is: /root",
-      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
-      "/model/HomePath/Username": "root",
-      "/model/HomePath/Is": " is: ",
-      "/model/HomePath/Path": "/root"
-    }
+    ]
   },
   "LogData": {
     "RawLogData": [
@@ -202,7 +185,13 @@ JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
 ,
     "LogLinesCount": 1,
-    "AnnotatedMatchElement": "/model/HomePath: The Path of the home directory shown by pwd of the user root is: /root\n  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user \n  /model/HomePath/Username: root\n  /model/HomePath/Is:  is: \n  /model/HomePath/Path: /root"
+    "AnnotatedMatchElement": {
+      "/model/HomePath": "The Path of the home directory shown by pwd of the user root is: /root",
+      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
+      "/model/HomePath/Username": "root",
+      "/model/HomePath/Is": " is: ",
+      "/model/HomePath/Path": "/root"
+    }
   }
 }
 {
@@ -220,14 +209,7 @@ read -r -d '' VAR << END
     "AffectedLogAtomValues": [
       "root",
       "/root"
-    ],
-    "ParsedLogAtom": {
-      "/model/HomePath": "The Path of the home directory shown by pwd of the user root is: /root",
-      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
-      "/model/HomePath/Username": "root",
-      "/model/HomePath/Is": " is: ",
-      "/model/HomePath/Path": "/root"
-    }
+    ]
   },
   "LogData": {
     "RawLogData": [
@@ -244,7 +226,13 @@ JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
 ,
     "LogLinesCount": 1,
-    "AnnotatedMatchElement": "/model/HomePath: The Path of the home directory shown by pwd of the user root is: /root\n  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user \n  /model/HomePath/Username: root\n  /model/HomePath/Is:  is: \n  /model/HomePath/Path: /root"
+    "AnnotatedMatchElement": {
+      "/model/HomePath": "The Path of the home directory shown by pwd of the user root is: /root",
+      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
+      "/model/HomePath/Username": "root",
+      "/model/HomePath/Is": " is: ",
+      "/model/HomePath/Path": "/root"
+    }
   }
 }
 {
@@ -262,14 +250,7 @@ read -r -d '' VAR << END
     "AffectedLogAtomValues": [
       "user",
       "/home/user"
-    ],
-    "ParsedLogAtom": {
-      "/model/HomePath": "The Path of the home directory shown by pwd of the user user is: /home/user",
-      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
-      "/model/HomePath/Username": "user",
-      "/model/HomePath/Is": " is: ",
-      "/model/HomePath/Path": "/home/user"
-    }
+    ]
   },
   "LogData": {
     "RawLogData": [
@@ -286,7 +267,13 @@ JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
 ,
     "LogLinesCount": 1,
-    "AnnotatedMatchElement": "/model/HomePath: The Path of the home directory shown by pwd of the user user is: /home/user\n  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user \n  /model/HomePath/Username: user\n  /model/HomePath/Is:  is: \n  /model/HomePath/Path: /home/user"
+    "AnnotatedMatchElement": {
+      "/model/HomePath": "The Path of the home directory shown by pwd of the user user is: /home/user",
+      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
+      "/model/HomePath/Username": "user",
+      "/model/HomePath/Is": " is: ",
+      "/model/HomePath/Path": "/home/user"
+    }
   }
 }
 {
@@ -304,14 +291,7 @@ read -r -d '' VAR << END
     "AffectedLogAtomValues": [
       "guest",
       "/home/guest"
-    ],
-    "ParsedLogAtom": {
-      "/model/HomePath": "The Path of the home directory shown by pwd of the user guest is: /home/guest",
-      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
-      "/model/HomePath/Username": "guest",
-      "/model/HomePath/Is": " is: ",
-      "/model/HomePath/Path": "/home/guest"
-    }
+    ]
   },
   "LogData": {
     "RawLogData": [
@@ -328,7 +308,13 @@ JSON_OUTPUT+=("$VAR")
 read -r -d '' VAR << END
 ,
     "LogLinesCount": 1,
-    "AnnotatedMatchElement": "/model/HomePath: The Path of the home directory shown by pwd of the user guest is: /home/guest\n  /model/HomePath/Pwd: The Path of the home directory shown by pwd of the user \n  /model/HomePath/Username: guest\n  /model/HomePath/Is:  is: \n  /model/HomePath/Path: /home/guest"
+    "AnnotatedMatchElement": {
+      "/model/HomePath": "The Path of the home directory shown by pwd of the user guest is: /home/guest",
+      "/model/HomePath/Pwd": "The Path of the home directory shown by pwd of the user ",
+      "/model/HomePath/Username": "guest",
+      "/model/HomePath/Is": " is: ",
+      "/model/HomePath/Path": "/home/guest"
+    }
   }
 }
 END
