@@ -1,10 +1,12 @@
-curl https://mirror.klaus-uwe.me/apache/kafka/2.5.0/kafka_2.12-2.7.0.tgz --output kafka.tgz
+source config
+
+curl $KAFKA_URL --output kafka.tgz
 tar xvf kafka.tgz > /dev/null
 rm kafka.tgz
 
-kafka_2.12-2.7.0/bin/zookeeper-server-start.sh kafka_2.12-2.7.0/config/zookeeper.properties > /dev/null &
+$KAFKA_VERSIONSTRING/bin/zookeeper-server-start.sh $KAFKA_VERSIONSTRING/config/zookeeper.properties > /dev/null &
 sleep 1
-kafka_2.12-2.7.0/bin/kafka-server-start.sh kafka_2.12-2.7.0/config/server.properties > /dev/null &
+$KAFKA_VERSIONSTRING/bin/kafka-server-start.sh $KAFKA_VERSIONSTRING/config/server.properties > /dev/null &
 
 sudo coverage run --source=./aminer -m unittest discover -s unit -p '*Test.py' > /dev/null
 exit_code1=$?
@@ -22,9 +24,9 @@ sudo rm /tmp/test4unixSocket.sock
 sudo rm /tmp/test5unixSocket.sock
 sudo rm /tmp/test6unixSocket.sock
 
-kafka_2.12-2.7.0/bin/kafka-server-stop.sh > /dev/null
-kafka_2.12-2.7.0/bin/zookeeper-server-stop.sh > /dev/null
-sudo rm -r kafka_2.12-2.7.0/
+$KAFKA_VERSIONSTRING/bin/kafka-server-stop.sh > /dev/null
+$KAFKA_VERSIONSTRING/bin/zookeeper-server-stop.sh > /dev/null
+sudo rm -r $KAFKA_VERSIONSTRING/
 sudo rm -r /tmp/zookeeper
 sudo rm -r /tmp/kafka-logs
 if [[ "$exit_code1" -ne 0 || "$exit_code2" -ne 0 ]]; then
