@@ -6,12 +6,12 @@ sudo mkdir /tmp/lib/aminer 2> /dev/null
 sudo chown -R $USER:$USER /tmp/lib/aminer 2> /dev/null
 sudo rm -r $AMINER_PERSISTENCE_PATH 2> /dev/null
 sudo chown -R aminer:aminer /tmp/lib/aminer 2> /dev/null
+sudo rm $OUT 2> /dev/null
 
 cp -r ./demo/aminerJsonInputDemo/json_logs /tmp/json_logs
 cp -r ./demo/aminerJsonInputDemo/windows_json_logs /tmp/windows_json_logs
 
-sudo chown -R aminer:aminer /tmp/lib 2> /dev/null
-sudo ./demo/aminerJsonInputDemo/json-demo.sh $1 > $OUT
+sudo ./demo/aminerJsonInputDemo/json-demo.sh $1 $OUT
 exit_code=$?
 
 OUTPUT=$(cat $OUT)
@@ -27,7 +27,7 @@ if grep -Fq "UnicodeDecodeError" $OUT || grep -Fq "Config-Error" $OUT || grep -F
 	sed '/Traceback/,$p' $OUT
 fi
 
-exit $exit_code
 sudo rm $OUT
 sudo rm -r /tmp/json_logs
 sudo rm -r /tmp/windows_json_logs
+exit $exit_code
