@@ -1,5 +1,7 @@
-sudo cp demo/aminerRemoteControl/demo-config.py /tmp/demo-config.py
-sudo sed -i 's/StreamPrinterEventHandler(analysis_context)/StreamPrinterEventHandler(analysis_context, stream=open("\/tmp\/log.txt", "a"))/g' /tmp/demo-config.py
+FILE=/tmp/demo-config.py
+CMD_PATH=/tmp/commands.txt
+sudo cp demo/aminerRemoteControl/demo-config.py $FILE
+sudo sed -i 's/StreamPrinterEventHandler(analysis_context)/StreamPrinterEventHandler(analysis_context, stream=open("\/tmp\/log.txt", "a"))/g' $FILE
 sudo mkdir /tmp/lib 2> /dev/null
 sudo mkdir /tmp/lib/aminer 2> /dev/null
 sudo mkdir /tmp/lib/aminer/log 2> /dev/null
@@ -8,13 +10,11 @@ sudo chown -R aminer:aminer /tmp/lib 2> /dev/null
 sudo rm /tmp/syslog 2> /dev/null
 touch /tmp/syslog
 
-FILE=/tmp/demo-config.py
 sudo aminer --config "$FILE" & > /dev/null
-
 sleep 1
 
-stdout=$(sudo aminerremotecontrol --exec-file /tmp/commands.txt)
-expected="File /tmp/commands.txt does not exist"
+stdout=$(sudo aminerremotecontrol --exec-file $CMD_PATH)
+expected="File $CMD_PATH does not exist"
 if [[ "$stdout" != "$expected" ]]; then
 	echo "$ERROR exec-file not exists."
 	echo "$stdout"
@@ -31,7 +31,7 @@ ERROR="Error at:"
 exit_code=0
 expected_list=""
 
-echo "print_config_property(analysis_context, 'Core.PersistenceDir')" >> /tmp/commands.txt
+echo "print_config_property(analysis_context, 'Core.PersistenceDir')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "print_config_property(analysis_context, 'Core.PersistenceDir')")
 expected="$PREFIX'\"Core.PersistenceDir\": /tmp/lib/aminer'"
 expected_list="${expected_list}${expected}
@@ -44,7 +44,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "print_config_property(analysis_context, 'Core.PersistencePeriod')" >> /tmp/commands.txt
+echo "print_config_property(analysis_context, 'Core.PersistencePeriod')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "print_config_property(analysis_context, 'Core.PersistencePeriod')")
 expected="$PREFIX'\"Resource \\\\\"Core.PersistencePeriod\\\\\" could not be found.\"'"
 expected_list="${expected_list}${expected}
@@ -65,7 +65,7 @@ valid_addresses=("'test123@gmail.com'" "'root@localhost'" )
 error_addresses=("'domain.user1@localhost'" "'root@notLocalhost'")
 for property in "${properties[@]}"; do
   for address in "${valid_addresses[@]}"; do
-    echo "change_config_property(analysis_context, $property, $address)" >> /tmp/commands.txt
+    echo "change_config_property(analysis_context, $property, $address)" >> $CMD_PATH
     stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $address)")
     expected="$PREFIX\"$property changed to $address successfully.\""
     expected_list="${expected_list}${expected}
@@ -79,7 +79,7 @@ for property in "${properties[@]}"; do
     fi
   done
   for address in "${error_addresses[@]}"; do
-    echo "change_config_property(analysis_context, $property, $address)" >> /tmp/commands.txt
+    echo "change_config_property(analysis_context, $property, $address)" >> $CMD_PATH
     stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $address)")
     expected="$PREFIX'FAILURE: MailAlerting.TargetAddress and MailAlerting.FromAddress must be email addresses!'"
     expected_list="${expected_list}${expected}
@@ -98,7 +98,7 @@ INTEGER_CONFIG_PROPERTIES=("'MailAlerting.AlertGraceTime'" "'MailAlerting.EventC
 STRING_CONFIG_PROPERTIES=("'MailAlerting.TargetAddress'" "'MailAlerting.FromAddress'" "'MailAlerting.SubjectPrefix'" "'LogPrefix'")
 
 for property in "${STRING_CONFIG_PROPERTIES[@]}"; do
-  echo "change_config_property(analysis_context, $property, 123)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, 123)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, 123)")
   expected="$PREFIX\"FAILURE: the value of the property $property must be of type <class 'str'>!\""
   expected_list="${expected_list}${expected}
@@ -110,7 +110,7 @@ for property in "${STRING_CONFIG_PROPERTIES[@]}"; do
 	  echo
 	  exit_code=1
   fi
-  echo "change_config_property(analysis_context, $property, 'root@localhost')" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, 'root@localhost')" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, 'root@localhost')")
   expected="$PREFIX\"$property changed to 'root@localhost' successfully.\""
   expected_list="${expected_list}${expected}
@@ -125,7 +125,7 @@ for property in "${STRING_CONFIG_PROPERTIES[@]}"; do
 done
 
 for property in "${INTEGER_CONFIG_PROPERTIES[@]}"; do
-  echo "change_config_property(analysis_context, $property, '1')" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, '1')" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, '1')")
   expected="$PREFIX\"FAILURE: the value of the property $property must be of type <class 'int'>!\""
   expected_list="${expected_list}${expected}
@@ -137,7 +137,7 @@ for property in "${INTEGER_CONFIG_PROPERTIES[@]}"; do
 	  echo
 	  exit_code=1
   fi
-  echo "change_config_property(analysis_context, $property, 1)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, 1)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, 1)")
   expected="$PREFIX\"$property changed to '1' successfully.\""
   if [[ "$stdout" == "$PREFIX'FAILURE: it is not safe to run the aminer with less than 32MB RAM.'" ]]; then
@@ -159,7 +159,7 @@ done
 properties=("'Log.StatisticsLevel'" "'Log.DebugLevel'")
 for property in "${properties[@]}"; do
   value=0
-  echo "change_config_property(analysis_context, $property, $value)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, $value)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $value)")
   expected="$PREFIX\"$property changed to '$value' successfully.\""
   expected_list="${expected_list}${expected}
@@ -172,7 +172,7 @@ for property in "${properties[@]}"; do
       exit_code=1
   fi
   value=1
-  echo "change_config_property(analysis_context, $property, $value)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, $value)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $value)")
   expected="$PREFIX\"$property changed to '$value' successfully.\""
   expected_list="${expected_list}${expected}
@@ -185,7 +185,7 @@ for property in "${properties[@]}"; do
       exit_code=1
   fi
   value=2
-  echo "change_config_property(analysis_context, $property, $value)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, $value)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $value)")
   expected="$PREFIX\"$property changed to '$value' successfully.\""
   expected_list="${expected_list}${expected}
@@ -198,7 +198,7 @@ for property in "${properties[@]}"; do
       exit_code=1
   fi
   value=-1
-  echo "change_config_property(analysis_context, $property, $value)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, $value)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $value)")
   expected="$PREFIX'FAILURE: STAT_LEVEL $value is not allowed. Allowed STAT_LEVEL values are 0, 1, 2.'"
   if [[ "$stdout" == "$PREFIX'FAILURE: DEBUG_LEVEL $value is not allowed. Allowed DEBUG_LEVEL values are 0, 1, 2.'" ]]; then
@@ -216,7 +216,7 @@ for property in "${properties[@]}"; do
       exit_code=1
   fi
   value=3
-  echo "change_config_property(analysis_context, $property, $value)" >> /tmp/commands.txt
+  echo "change_config_property(analysis_context, $property, $value)" >> $CMD_PATH
   stdout=$(sudo aminerremotecontrol --exec "change_config_property(analysis_context, $property, $value)")
   expected="$PREFIX'FAILURE: STAT_LEVEL $value is not allowed. Allowed STAT_LEVEL values are 0, 1, 2.'"
   if [[ "$stdout" == "$PREFIX'FAILURE: DEBUG_LEVEL $value is not allowed. Allowed DEBUG_LEVEL values are 0, 1, 2.'" ]]; then
@@ -235,7 +235,7 @@ for property in "${properties[@]}"; do
   fi
 done
 
-echo "rename_registered_analysis_component(analysis_context,'NewMatchPathValueCombo','NewMatchPathValueComboDetector')" >> /tmp/commands.txt
+echo "rename_registered_analysis_component(analysis_context,'NewMatchPathValueCombo','NewMatchPathValueComboDetector')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "rename_registered_analysis_component(analysis_context,'NewMatchPathValueCombo','NewMatchPathValueComboDetector')")
 expected="$PREFIX\"Component 'NewMatchPathValueCombo' renamed to 'NewMatchPathValueComboDetector' successfully.\""
 expected_list="${expected_list}${expected}
@@ -248,7 +248,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "rename_registered_analysis_component(analysis_context,'NewMatchPathValueComboDetector', 222)" >> /tmp/commands.txt
+echo "rename_registered_analysis_component(analysis_context,'NewMatchPathValueComboDetector', 222)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "rename_registered_analysis_component(analysis_context,'NewMatchPathValueComboDetector', 222)")
 expected="$PREFIX\"FAILURE: the parameters 'old_component_name' and 'new_component_name' must be of type str.\""
 expected_list="${expected_list}${expected}
@@ -261,7 +261,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "rename_registered_analysis_component(analysis_context,'NonExistingDetector','NewMatchPathValueComboDetector')" >> /tmp/commands.txt
+echo "rename_registered_analysis_component(analysis_context,'NonExistingDetector','NewMatchPathValueComboDetector')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "rename_registered_analysis_component(analysis_context,'NonExistingDetector','NewMatchPathValueComboDetector')")
 expected="$PREFIX\"FAILURE: the component 'NonExistingDetector' does not exist.\""
 expected_list="${expected_list}${expected}
@@ -274,33 +274,33 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'auto_include_flag', False)" >> /tmp/commands.txt
-stdout=$(sudo aminerremotecontrol --exec "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'auto_include_flag', False)")
-expected="$PREFIX\"'NewMatchPathValueComboDetector.auto_include_flag' changed from False to False successfully.\""
+echo "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'learn_mode', False)" >> $CMD_PATH
+stdout=$(sudo aminerremotecontrol --exec "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'learn_mode', False)")
+expected="$PREFIX\"'NewMatchPathValueComboDetector.learn_mode' changed from False to False successfully.\""
 expected_list="${expected_list}${expected}
 "
 if [[ "$stdout" != "$expected" ]]; then
-	echo "$ERROR changes the 'auto_include_flag' of the 'NewMatchPathValueComboDetector' to False."
+	echo "$ERROR changes the 'learn_mode' of the 'NewMatchPathValueComboDetector' to False."
 	echo "$stdout"
 	echo "Expected: $expected"
 	echo
 	exit_code=1
 fi
 
-echo "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'auto_include_flag', 'True')" >> /tmp/commands.txt
-stdout=$(sudo aminerremotecontrol --exec "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'auto_include_flag', 'True')")
-expected="$PREFIX\"FAILURE: property 'NewMatchPathValueComboDetector.auto_include_flag' must be of type <class 'bool'>!\""
+echo "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'learn_mode', 'True')" >> $CMD_PATH
+stdout=$(sudo aminerremotecontrol --exec "change_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'learn_mode', 'True')")
+expected="$PREFIX\"FAILURE: property 'NewMatchPathValueComboDetector.learn_mode' must be of type <class 'bool'>!\""
 expected_list="${expected_list}${expected}
 "
 if [[ "$stdout" != "$expected" ]]; then
-	echo "$ERROR changes the 'auto_include_flag' of the 'NewMatchPathValueComboDetector' wrong Type."
+	echo "$ERROR changes the 'learn_mode' of the 'NewMatchPathValueComboDetector' wrong Type."
 	echo "$stdout"
 	echo "Expected: $expected"
 	echo
 	exit_code=1
 fi
 
-echo "print_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'target_path_list')" >> /tmp/commands.txt
+echo "print_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'target_path_list')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "print_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'target_path_list')")
 expected="$PREFIX'\"NewMatchPathValueComboDetector.target_path_list\": [\"/model/IPAddresses/Username\", \"/model/IPAddresses/IP\"]'"
 expected_list="${expected_list}${expected}
@@ -313,7 +313,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "print_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'other_path_list')" >> /tmp/commands.txt
+echo "print_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'other_path_list')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "print_attribute_of_registered_analysis_component(analysis_context, 'NewMatchPathValueComboDetector',  'other_path_list')")
 expected="$PREFIX\"FAILURE: the component 'NewMatchPathValueComboDetector' does not have an attribute named 'other_path_list'.\""
 expected_list="${expected_list}${expected}
@@ -326,8 +326,8 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', NewMatchPathDetector(analysis_context.aminer_config, analysis_context.atomizer_factory.atom_handler_list, auto_include_flag=True), 'NewMatchPathDet')" >> /tmp/commands.txt
-stdout=$(sudo aminerremotecontrol --exec "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', NewMatchPathDetector(analysis_context.aminer_config, analysis_context.atomizer_factory.atom_handler_list, auto_include_flag=True), 'NewMatchPathDet')")
+echo "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', NewMatchPathDetector(analysis_context.aminer_config, analysis_context.atomizer_factory.atom_handler_list, learn_mode=True), 'NewMatchPathDet')" >> $CMD_PATH
+stdout=$(sudo aminerremotecontrol --exec "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', NewMatchPathDetector(analysis_context.aminer_config, analysis_context.atomizer_factory.atom_handler_list, learn_mode=True), 'NewMatchPathDet')")
 expected="$PREFIX\"Component 'NewMatchPathDet' added to 'AtomFilter' successfully.\""
 expected_list="${expected_list}${expected}
 "
@@ -339,7 +339,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', 'StringDetector', 'StringDetector')" >> /tmp/commands.txt
+echo "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', 'StringDetector', 'StringDetector')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "add_handler_to_atom_filter_and_register_analysis_component(analysis_context, 'AtomFilter', 'StringDetector', 'StringDetector')")
 expected="$PREFIX\"FAILURE: 'component' must implement the AtomHandlerInterface!\""
 expected_list="${expected_list}${expected}
@@ -352,7 +352,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "save_current_config(analysis_context,'/tmp/config.py')" >> /tmp/commands.txt
+echo "save_current_config(analysis_context,'/tmp/config.py')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "save_current_config(analysis_context,'/tmp/config.py')")
 expected="${PREFIX}\"${NOT_FOUND_WARNINGS}Successfully saved the current config to /tmp/config.py.\""
 expected_list="${expected_list}${expected}
@@ -366,9 +366,9 @@ if [[ "$stdout" != "$expected" ]]; then
 fi
 sudo rm /tmp/config.py
 
-echo "save_current_config(analysis_context,'[dd/path/config.py')" >> /tmp/commands.txt
-stdout=$(sudo aminerremotecontrol --exec "save_current_config(analysis_context,'[dd/path/config.py')")
-expected="${PREFIX}\"${NOT_FOUND_WARNINGS}FAILURE: file '[dd/path/config.py' could not be found or opened!\""
+echo "save_current_config(analysis_context,'[/path/config.py')" >> $CMD_PATH
+stdout=$(sudo aminerremotecontrol --exec "save_current_config(analysis_context,'[/path/config.py')")
+expected="${PREFIX}'Exception: [/path/config.py is not a valid filename!'"
 expected_list="${expected_list}${expected}
 "
 if [[ "$stdout" != "$expected" ]]; then
@@ -379,7 +379,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "save_current_config(analysis_context,'/notExistingPath/config.py')" >> /tmp/commands.txt
+echo "save_current_config(analysis_context,'/notExistingPath/config.py')" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "save_current_config(analysis_context,'/notExistingPath/config.py')")
 expected="${PREFIX}\"${NOT_FOUND_WARNINGS}FAILURE: file '/notExistingPath/config.py' could not be found or opened!\""
 expected_list="${expected_list}${expected}
@@ -392,7 +392,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "persist_all()" >> /tmp/commands.txt
+echo "persist_all()" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "persist_all()")
 expected="${PREFIX}'OK'"
 expected_list="${expected_list}${expected}
@@ -405,7 +405,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-# echo "create_backup(analysis_context)" >> /tmp/commands.txt
+# echo "create_backup(analysis_context)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "create_backup(analysis_context)")
 expected="${PREFIX}'Created backup "
 # expected_list="${expected_list}${expected}
@@ -418,7 +418,7 @@ if [[ "$stdout" != "$expected"* ]]; then
 	exit_code=1
 fi
 
-# echo "list_backups(analysis_context)" >> /tmp/commands.txt
+# echo "list_backups(analysis_context)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "list_backups(analysis_context)")
 expected="${PREFIX}'\"backups\": ["
 # expected_list="${expected_list}${expected}
@@ -432,7 +432,7 @@ if [[ "$stdout" != "$expected"* ]]; then
 fi
 
 timestamp=$(date +%s)
-echo "allowlist_event_in_component(analysis_context,'EnhancedNewValueCombo',($timestamp,'/model/path'),allowlisting_data=None)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'EnhancedNewValueCombo',($timestamp,'/model/path'),allowlisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'EnhancedNewValueCombo',($timestamp,'/model/path'),allowlisting_data=None)")
 expected="${PREFIX}\"Allowlisted path(es) /model/DailyCron/UName, /model/DailyCron/JobNumber with ($timestamp, '/model/path').\""
 expected_list="${expected_list}${expected}
@@ -445,7 +445,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "allowlist_event_in_component(analysis_context,'MissingMatch',(' ','/model/DiskReport/Space'),allowlisting_data=-1)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'MissingMatch',(' ','/model/DiskReport/Space'),allowlisting_data=-1)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'MissingMatch',(' ','/model/DiskReport/Space'),allowlisting_data=-1)")
 expected="${PREFIX}\"Updated ' ' in '/model/DiskReport/Space' to new interval 2.\""
 expected_list="${expected_list}${expected}
@@ -458,7 +458,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "allowlist_event_in_component(analysis_context,'NewMatchPath','/model/somepath',allowlisting_data=None)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'NewMatchPath','/model/somepath',allowlisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'NewMatchPath','/model/somepath',allowlisting_data=None)")
 expected="${PREFIX}'Allowlisted path(es) /model/somepath in Analysis.NewMatchPathDetector.'"
 expected_list="${expected_list}${expected}
@@ -471,7 +471,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "allowlist_event_in_component(analysis_context,'NewMatchPathValueComboDetector','/model/somepath',allowlisting_data=None)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'NewMatchPathValueComboDetector','/model/somepath',allowlisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'NewMatchPathValueComboDetector','/model/somepath',allowlisting_data=None)")
 expected="${PREFIX}'Allowlisted path(es) /model/IPAddresses/Username, /model/IPAddresses/IP with /model/somepath.'"
 expected_list="${expected_list}${expected}
@@ -484,7 +484,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "allowlist_event_in_component(analysis_context,'NewMatchIdValueComboDetector','/model/somepath',allowlisting_data=None)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'NewMatchIdValueComboDetector','/model/somepath',allowlisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'NewMatchIdValueComboDetector','/model/somepath',allowlisting_data=None)")
 expected="${PREFIX}'Allowlisted path(es) /model/type/path/name, /model/type/syscall/syscall with /model/somepath.'"
 expected_list="${expected_list}${expected}
@@ -497,7 +497,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "allowlist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',allowlisting_data=None)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',allowlisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',allowlisting_data=None)")
 expected="${PREFIX}'Allowlisted path /model/somepath.'"
 expected_list="${expected_list}${expected}
@@ -510,7 +510,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "allowlist_event_in_component(analysis_context,'NewMatchPathValue','/model/somepath',allowlisting_data=None)" >> /tmp/commands.txt
+echo "allowlist_event_in_component(analysis_context,'NewMatchPathValue','/model/somepath',allowlisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "allowlist_event_in_component(analysis_context,'NewMatchPathValue','/model/somepath',allowlisting_data=None)")
 expected="${PREFIX}'Allowlisted path(es) /model/DailyCron/Job Number, /model/IPAddresses/Username with /model/somepath.'"
 expected_list="${expected_list}${expected}
@@ -523,7 +523,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "blocklist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',blocklisting_data=None)" >> /tmp/commands.txt
+echo "blocklist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',blocklisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "blocklist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',blocklisting_data=None)")
 expected="${PREFIX}'Blocklisted path /model/somepath.'"
 expected_list="${expected_list}${expected}
@@ -536,7 +536,7 @@ if [[ "$stdout" != "$expected" ]]; then
 	exit_code=1
 fi
 
-echo "blocklist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',blocklisting_data=None)" >> /tmp/commands.txt
+echo "blocklist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',blocklisting_data=None)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "blocklist_event_in_component(analysis_context,'EventCorrelationDetector','/model/somepath',blocklisting_data=None)")
 expected="${PREFIX}'Blocklisted path /model/somepath.'"
 expected_list="${expected_list}${expected}
@@ -550,7 +550,7 @@ if [[ "$stdout" != "$expected" ]]; then
 fi
 EXEC_TIME=$(($(date +%s)-START_TIME))
 
-echo "print_current_config(analysis_context)" >> /tmp/commands.txt
+echo "print_current_config(analysis_context)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "print_current_config(analysis_context)")
 expected="$PREFIX None"
 if [[ "$stdout" == "$expected" ]]; then
@@ -564,7 +564,7 @@ stdout=$(echo "$stdout" | sed -e "s/\"next_persist_time\".*,//")
 expected_list="${expected_list}${stdout}
 "
 
-echo "reopen_event_handler_streams(analysis_context)" >> /tmp/commands.txt
+echo "reopen_event_handler_streams(analysis_context)" >> $CMD_PATH
 stdout=$(sudo aminerremotecontrol --exec "reopen_event_handler_streams(analysis_context)")
 expected="$PREFIX'Reopened all StreamPrinterEventHandler streams.'"
 if [[ "$stdout" != "$expected" ]]; then
@@ -590,7 +590,7 @@ sudo aminer --config "$FILE" & > /dev/null
 sleep 1
 
 START_TIME=$(date +%s)
-stdout=$(sudo aminerremotecontrol --exec-file /tmp/commands.txt)
+stdout=$(sudo aminerremotecontrol --exec-file $CMD_PATH)
 stdout=$(echo "$stdout" | sed -e "s/\"next_persist_time\".*,//")
 expected_list=$(echo "$expected_list" | sed -e "s/\"next_persist_time\".*,//")
 if [[ "$stdout" != "$expected_list" ]]; then
@@ -605,7 +605,7 @@ EXEC_FILE_TIME=$(($(date +%s)-START_TIME))
 
 sudo pkill -x aminer
 sleep 2 & wait $!
-sudo rm /tmp/commands.txt
+sudo rm $CMD_PATH
 echo "Command execution time with --exec ${EXEC_TIME}s"
 echo "Command execution time with --exec-file ${EXEC_FILE_TIME}s"
 exit $exit_code
