@@ -148,14 +148,14 @@ class HistogramAnalysisTest(TestBase):
         histogram_analysis = HistogramAnalysis(self.aminer_config, [(histogram_data.property_path, modulo_time_bin_definition)], 604800,
                                                [self.stream_printer_event_handler], True, 'Default')
         self.analysis_context.register_component(histogram_analysis, description)
-        match_element = MatchElement(self.match_crontab, start_time, start_time, [])
+        match_element = MatchElement(self.match_crontab, str(start_time).encode(), start_time, None)
 
         t = time.time()
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, histogram_analysis)
         histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, histogram_analysis)
         histogram_analysis.receive_atom(log_atom)
         self.assertEqual(self.output_stream.getvalue(), '')
@@ -171,7 +171,7 @@ class HistogramAnalysisTest(TestBase):
 
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, histogram_analysis)
         histogram_analysis.receive_atom(log_atom)
         self.assertEqual(self.output_stream.getvalue(), '')
@@ -188,14 +188,14 @@ class HistogramAnalysisTest(TestBase):
         histogram_analysis = HistogramAnalysis(self.aminer_config, [(histogram_data.property_path, modulo_time_bin_definition)], 604800,
                                                [self.stream_printer_event_handler], True, 'Default')
         self.analysis_context.register_component(histogram_analysis, description)
-        match_element = MatchElement(self.match_crontab, start_time, start_time, [])
+        match_element = MatchElement(self.match_crontab, str(start_time).encode(), start_time, None)
 
         t = time.time()
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, histogram_analysis)
         histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, histogram_analysis)
         histogram_analysis.receive_atom(log_atom)
 
@@ -215,7 +215,7 @@ class HistogramAnalysisTest(TestBase):
         histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
 
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, histogram_analysis)
         histogram_analysis.receive_atom(log_atom)
@@ -243,14 +243,14 @@ class HistogramAnalysisTest(TestBase):
             self.aminer_config, histogram_data.property_path, modulo_time_bin_definition, 604800,
             [self.stream_printer_event_handler], True, 'Default')
         self.analysis_context.register_component(path_dependent_histogram_analysis, description)
-        match_element = MatchElement(self.match_crontab, start_time, start_time, [])
+        match_element = MatchElement(self.match_crontab, str(start_time).encode(), start_time, None)
 
         t = time.time()
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         self.assertEqual(self.output_stream.getvalue(), '')
@@ -263,18 +263,18 @@ class HistogramAnalysisTest(TestBase):
 
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
-        match_element = MatchElement(self.match_crontab, start_time, start_time, [])
+        match_element = MatchElement(self.match_crontab, str(start_time).encode(), start_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
 
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         self.assertEqual(self.output_stream.getvalue(), '')
@@ -295,14 +295,14 @@ class HistogramAnalysisTest(TestBase):
             self.aminer_config, histogram_data.property_path, modulo_time_bin_definition, 604800,
             [self.stream_printer_event_handler], True, 'Default')
         self.analysis_context.register_component(path_dependent_histogram_analysis, description)
-        match_element = MatchElement(self.match_crontab, start_time, start_time, [])
+        match_element = MatchElement(self.match_crontab, str(start_time).encode(), start_time, None)
 
         t = time.time()
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         self.assertEqual(self.output_stream.getvalue(), self.__expected_string_path_dependent_histogram_analysis % (
@@ -321,18 +321,18 @@ class HistogramAnalysisTest(TestBase):
 
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
-        match_element = MatchElement(self.match_crontab, start_time, start_time, [])
+        match_element = MatchElement(self.match_crontab, str(start_time).encode(), start_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
         histogram_data.add_value(start_time)
         histogram_data.add_value(end_time)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
 
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
-        match_element = MatchElement(self.match_crontab, end_time, end_time, [])
+        match_element = MatchElement(self.match_crontab, str(end_time).encode(), end_time, None)
         log_atom = LogAtom(histogram_data.bin_data, ParserMatch(match_element), t + diff, path_dependent_histogram_analysis)
         path_dependent_histogram_analysis.receive_atom(log_atom)
         self.assertEqual(self.output_stream.getvalue(), self.__expected_string_path_dependent_histogram_analysis % (
