@@ -15,17 +15,7 @@ class FirstDataModelElementTest(TestBase):
     me3 = DummyFixedDataModelElement("me3", b"Random string2")
     children = [me1, me2, me3]
 
-    def test1get_id(self):
-        """Test if get_id works properly."""
-        first_match_me = FirstMatchModelElement(self.id_, self.children)
-        self.assertEqual(first_match_me.get_id(), self.id_)
-
-    def test2get_child_elements(self):
-        """Test if get_child_elements returns None."""
-        first_match_me = FirstMatchModelElement(self.id_, self.children)
-        self.assertEqual(first_match_me.get_child_elements(), self.children)
-
-    def test3get_match_element_valid_match(self):
+    def test1get_match_element_valid_match(self):
         """Parse matching substring from MatchContext and check if the MatchContext was updated with all characters."""
         data = b"The first fixed string. Random string23."
         value = b"The first fixed string."
@@ -55,7 +45,7 @@ class FirstDataModelElementTest(TestBase):
         match_element = first_match_me.get_match_element(self.path, match_context)
         self.compare_match_results(data, match_element, match_context, self.id_ + "/me3", self.path, value, value, None)
 
-    def test4get_match_element_no_match(self):
+    def test2get_match_element_no_match(self):
         """Parse not matching substring from MatchContext and check if the MatchContext was not changed."""
         data = b"some none matching string"
         match_context = DummyMatchContext(data)
@@ -75,7 +65,7 @@ class FirstDataModelElementTest(TestBase):
         match_element = first_match_me.get_match_element(self.path, match_context)
         self.compare_no_match_results(data, match_element, match_context)
 
-    def test5element_id_input_validation(self):
+    def test3element_id_input_validation(self):
         """Check if element_id is validated."""
         self.assertRaises(ValueError, FirstMatchModelElement, "", self.children)  # empty element_id
         self.assertRaises(TypeError, FirstMatchModelElement, None, self.children)  # None element_id
@@ -89,7 +79,7 @@ class FirstDataModelElementTest(TestBase):
         self.assertRaises(TypeError, FirstMatchModelElement, (), self.children)  # empty tuple element_id is not allowed
         self.assertRaises(TypeError, FirstMatchModelElement, set(), self.children)  # empty set element_id is not allowed
 
-    def test6children_input_validation(self):
+    def test4children_input_validation(self):
         """Check if children is validated."""
         self.assertRaises(TypeError, FirstMatchModelElement, self.id_, "path")  # string children
         self.assertRaises(TypeError, FirstMatchModelElement, self.id_, None)  # None children
@@ -104,7 +94,7 @@ class FirstDataModelElementTest(TestBase):
         self.assertRaises(TypeError, FirstMatchModelElement, self.id_, ())  # empty tuple children is not allowed
         self.assertRaises(TypeError, FirstMatchModelElement, self.id_, set())  # empty set children is not allowed
 
-    def test7get_match_element_match_context_input_validation(self):
+    def test5get_match_element_match_context_input_validation(self):
         """Check if an exception is raised, when other classes than MatchContext are used in get_match_element."""
         model_element = FirstMatchModelElement(self.id_, self.children)
         data = b"abcdefghijklmnopqrstuvwxyz.!?"
