@@ -113,22 +113,7 @@ class JsonModelElementTest(TestBase):
     }}
     key_parser_dict_array_of_arrays = {"a": [[DummyFixedDataModelElement("abc", b"abc")]]}
 
-    def test1get_id(self):
-        """Test if get_id works properly."""
-        json_me = JsonModelElement(self.id_, self.key_parser_dict)
-        self.assertEqual(json_me.get_id(), self.id_)
-
-    def test2get_child_elements(self):
-        """Test if get_child_elements returns None."""
-        k = self.key_parser_dict
-        json_me = JsonModelElement(self.id_, self.key_parser_dict)
-        self.assertEqual(json_me.get_child_elements(), [
-            k["menu"]["id"], k["menu"]["value"], [
-                k["menu"]["popup"]["menuitem"][0]["value"], k["menu"]["popup"]["menuitem"][0]["onclick"],
-                k["menu"]["popup"]["menuitem"][0]["optional_key_clickable"], k["menu"]["popup"]["menuitem"][1]["value"],
-                k["menu"]["popup"]["menuitem"][1]["onclick"], k["menu"]["popup"]["menuitem"][1]["clickable"]]])
-
-    def test3get_match_element_valid_match(self):
+    def test1get_match_element_valid_match(self):
         """Parse matching substring from MatchContext and check if the MatchContext was updated with all characters."""
         json_model_element = JsonModelElement(self.id_, self.key_parser_dict)
         data = self.single_line_json
@@ -215,7 +200,7 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test4get_match_element_with_optional_key(self):
+    def test2get_match_element_with_optional_key(self):
         """Validate optional keys with the optional_key_prefix."""
         json_model_element = JsonModelElement(self.id_, self.key_parser_dict)
         data = self.single_line_with_optional_key_json
@@ -237,7 +222,23 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test5get_match_element_with_allow_all(self):
+        json_model_element = JsonModelElement(self.id_, self.empty_key_parser_dict)
+        data = b'{"key": "value"}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(data)).encode()
+        match_context.match_data = data[len(match_context.match_string):]
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        json_model_element = JsonModelElement(self.id_, self.empty_key_parser_dict)
+        data = b'{"key": "another not matching value"}'
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        self.compare_no_match_results(data, match_element, match_context)
+
+    def test3get_match_element_with_allow_all(self):
         """Test a simplified key_parser_dict with ALLOW_ALL."""
         json_model_element = JsonModelElement(self.id_, self.key_parser_dict_allow_all)
         data = self.single_line_json
@@ -267,21 +268,171 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test6get_match_element_null_value(self):
-        """Test if null values are parsed to "null"."""
+    def test4get_match_element_with_nullable_values(self):
+        """Test if nullable values are working as intended."""
+        # test functionality with objects
+        key_parser_dict = {"+a": DummyFixedDataModelElement("a", b"a")}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data_null = b'{"a": null}'
+        data_empty = b"{}"
+        data = b'{"a": "a"}'
+        data_object_null = b'{"a": {"b": null}}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_null)
+        match_context = DummyMatchContext(data_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        # test with null value
+        key_parser_dict = {"+a": DummyFixedDataModelElement("a", b"null")}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": "null"}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_null)
+        match_context = DummyMatchContext(data_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        # test with null key
+        key_parser_dict = {"+null": DummyFixedDataModelElement("a", b"null")}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"null": "null"}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        null = b'{"null": null}'
+        value = json.loads(null)
+        match_context = DummyMatchContext(null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        # test functionality with arrays
+        key_parser_dict = {"+a": [DummyFixedDataModelElement("a", b"a")]}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": ["a"]}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_null)
+        match_context = DummyMatchContext(data_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        # test functionality with json dicts
+        key_parser_dict = {"+a": {"b": DummyFixedDataModelElement("b", b"b")}}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": {"b": "b"}}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_null)
+        match_context = DummyMatchContext(data_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        # no match with null in object
+        key_parser_dict = {"+a": {"b": DummyFixedDataModelElement("b", b"null")}}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        match_context = DummyMatchContext(data_object_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        self.compare_no_match_results(data_object_null, match_element, match_context)
+
+        # test interchangeability with optional_key_prefix
+        key_parser_dict = {"+optional_key_a": DummyFixedDataModelElement("a", b"a")}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": "a"}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_null)
+        match_context = DummyMatchContext(data_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_empty)
+        match_context = DummyMatchContext(data_empty)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_empty, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        key_parser_dict = {"optional_key_+a": DummyFixedDataModelElement("a", b"a")}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": "a"}'
+        value = json.loads(data)
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_null)
+        match_context = DummyMatchContext(data_null)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_null, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+        value = json.loads(data_empty)
+        match_context = DummyMatchContext(data_empty)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        match_context.match_string = str(json.loads(match_context.match_string)).encode()
+        self.compare_match_results(
+            data_empty, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
+
+    def test5get_match_element_null_value(self):
+        """Test if null keys and values can be used."""
         key_parser_dict = {
             "works": DummyFirstMatchModelElement("id", [
                 DummyFixedDataModelElement("abc", b"abc"), DummyFixedDataModelElement("123", b"123")]),
-            "null": DummyFirstMatchModelElement("wordlist", [
-                DummyFixedDataModelElement("allowed", b"allowed value"), DummyFixedDataModelElement("problem", b"null")])}
+            "null": "NULL_OBJECT"
+        }
         data1 = b"""{
-            "works": "abc",
-            "null": "allowed value"
-        }"""
-        data2 = b"""{
             "works": "123",
             "null": null
         }"""
+        data2 = b"""{"a": {"b": "c"}}"""
+        data3 = b"""{"a": null}"""
         json_model_element = JsonModelElement(self.id_, key_parser_dict)
         data = data1
         value = json.loads(data)
@@ -292,6 +443,8 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
+        key_parser_dict = {"a": {"b": DummyFixedDataModelElement("c", b"c")}}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
         data = data2
         value = json.loads(data)
         match_context = DummyMatchContext(data)
@@ -301,7 +454,12 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test7get_match_element_with_umlaut(self):
+        data = data3
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        self.compare_no_match_results(data, match_element, match_context)
+
+    def test6get_match_element_with_umlaut(self):
         """Test if ä ö ü are used correctly."""
         key_parser_dict = {"works": DummyFixedDataModelElement("abc", "a ä ü ö z".encode("utf-8"))}
         data = """{
@@ -316,7 +474,7 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test8get_match_element_same_value_as_key(self):
+    def test7get_match_element_same_value_as_key(self):
         """Test if object with the same key-value pairs are parsed correctly."""
         key_parser_dict = {"abc": DummyFirstMatchModelElement("first", [
             DummyFixedDataModelElement("abc", b"abc"), DummyFixedDataModelElement("abc", b"ab"), DummyFixedDataModelElement("abc", b"bc"),
@@ -381,14 +539,14 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test9get_match_element_empty_array_empty_object_null(self):
-        """Test if the keywords EMPTY_ARRAY, EMPTY_OBJECT, EMPTY_STRING,  and None (null) work properly."""
+    def test8get_match_element_empty_array_empty_object_null(self):
+        """Test if the keywords EMPTY_ARRAY, EMPTY_OBJECT, EMPTY_STRING,  and None NULL_OBJECT work properly."""
         key_parser_dict = {"menu": {
             "id": "EMPTY_OBJECT",
             "value": "EMPTY_ARRAY",
             "popup": {
                 "menuitem": [{
-                    "value": DummyFixedDataModelElement("null", b"null"),
+                    "value": "NULL_OBJECT",
                     "onclick": DummyFirstMatchModelElement("buttonOnclick", [
                         DummyFixedDataModelElement("create_new_doc", b"CreateNewDoc()"),
                         DummyFixedDataModelElement("open_doc", b"OpenDoc()"), DummyFixedDataModelElement("close_doc", b"CloseDoc()")]),
@@ -462,7 +620,7 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test10get_match_element_float_exponents(self):
+    def test9get_match_element_float_exponents(self):
         """
         Parse float values with exponents.
         The principle of only testing dummy classes can not be applied here, as the functionality between the JsonModelElement and
@@ -531,7 +689,7 @@ class JsonModelElementTest(TestBase):
         self.compare_match_results(
             data, match_element, match_context, self.id_, self.path, str(value).encode(), value, match_element.children)
 
-    def test11get_match_element_allow_all_fields(self):
+    def test10get_match_element_allow_all_fields(self):
         """Parse matching substring from MatchContext using the allow_all_fields parameter."""
         json_model_element = JsonModelElement(self.id_, self.key_parser_dict_allow_all_fields, allow_all_fields=True)
         data = self.single_line_json
@@ -548,7 +706,7 @@ class JsonModelElementTest(TestBase):
         match_element = json_model_element.get_match_element(self.path, match_context)
         self.compare_no_match_results(data, match_element, match_context)
 
-    def test12get_match_element_no_match(self):
+    def test11get_match_element_no_match(self):
         """Parse not matching substring from MatchContext and check if the MatchContext was not changed."""
         json_model_element = JsonModelElement(self.id_, self.key_parser_dict)
         # missing key
@@ -597,7 +755,28 @@ class JsonModelElementTest(TestBase):
         match_element = json_model_element.get_match_element(self.path, match_context)
         self.compare_no_match_results(data, match_element, match_context)
 
-    def test13element_id_input_validation(self):
+        key_parser_dict = {"a": [{"b": DummyFixedDataModelElement("b", b"ef")}]}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": [{"b": "fe"}]}'
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        self.compare_no_match_results(data, match_element, match_context)
+
+        key_parser_dict = {"a": [DummyFixedDataModelElement("a", b"gh")]}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": ["hg"]}'
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        self.compare_no_match_results(data, match_element, match_context)
+
+        key_parser_dict = {"a": {"b": DummyFixedDataModelElement("c", b"c")}}
+        json_model_element = JsonModelElement(self.id_, key_parser_dict)
+        data = b'{"a": "b"}'
+        match_context = DummyMatchContext(data)
+        match_element = json_model_element.get_match_element(self.path, match_context)
+        self.compare_no_match_results(data, match_element, match_context)
+
+    def test12element_id_input_validation(self):
         """Check if element_id is validated."""
         self.assertRaises(ValueError, JsonModelElement, "", self.key_parser_dict)  # empty element_id
         self.assertRaises(TypeError, JsonModelElement, None, self.key_parser_dict)  # None element_id
@@ -611,7 +790,7 @@ class JsonModelElementTest(TestBase):
         self.assertRaises(TypeError, JsonModelElement, (), self.key_parser_dict)  # empty tuple element_id is not allowed
         self.assertRaises(TypeError, JsonModelElement, set(), self.key_parser_dict)  # empty set element_id is not allowed
 
-    def test14key_parser_dict_input_validation(self):
+    def test13key_parser_dict_input_validation(self):
         """Check if key_parser_dict is validated."""
         self.assertRaises(TypeError, JsonModelElement, self.id_, "path")  # string key_parser_dict
         self.assertRaises(TypeError, JsonModelElement, self.id_, None)  # None key_parser_dict
@@ -630,19 +809,33 @@ class JsonModelElementTest(TestBase):
         self.assertRaises(TypeError, JsonModelElement, self.id_, ())  # empty tuple key_parser_dict is not allowed
         self.assertRaises(TypeError, JsonModelElement, self.id_, set())  # empty set key_parser_dict is not allowed
 
-    def test15optional_key_prefix_input_validation(self):
+    def test14optional_key_prefix_input_validation(self):
         """Check if optional_key_prefix is validated."""
-        self.assertRaises(ValueError, JsonModelElement, self.id_, self.key_parser_dict, "")  # empty optional_key_prefix
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, None)  # None optional_key_prefix
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, b"path")  # bytes optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, True)  # boolean optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, 123)  # integer optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, 123.22)  # float optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, {"id": "path"})  # dict not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, ["path"])  # list optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, [])  # empty list optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, ())  # empty tuple optional_key_prefix is not allowed
-        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, set())  # empty set optional_key_prefix not allowed
+        self.assertRaises(ValueError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix="")
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=None)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=b"path")
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=True)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=123)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=123.22)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix={"id": "path"})
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=["path"])
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=[])
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=())
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix=set())
+
+    def test15nullable_key_prefix_input_validation(self):
+        """Check if optional_key_prefix is validated."""
+        self.assertRaises(ValueError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix="")
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=None)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=b"path")
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=True)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=123)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=123.22)
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix={"id": "path"})
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=["path"])
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=[])
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=())
+        self.assertRaises(TypeError, JsonModelElement, self.id_, self.key_parser_dict, nullable_key_prefix=set())
 
     def test16allow_all_fields_input_validation(self):
         """Check if allow_all_fields is validated."""
@@ -677,6 +870,10 @@ class JsonModelElementTest(TestBase):
         self.assertRaises(AttributeError, model_element.get_match_element, self.path, ())
         self.assertRaises(AttributeError, model_element.get_match_element, self.path, model_element)
 
+    def test18same_optional_key_and_nullable_key_prefix(self):
+        """Test if an exception is thrown if the optional_key_prefix is the same as the nullable_key_prefix."""
+        self.assertRaises(ValueError, JsonModelElement, self.id_, self.key_parser_dict, optional_key_prefix="+", nullable_key_prefix="+")
+
 
 if __name__ == "__main__":
     unittest.main()
