@@ -16,17 +16,7 @@ class SequenceModelElementTest(TestBase):
                       MatchElement("path/sequence/1", b"string1 ", b"string1 ", None),
                       MatchElement("path/sequence/2", b"string2", b"string2", None)]
 
-    def test1get_id(self):
-        """Test if get_id works properly."""
-        sequence_me = SequenceModelElement(self.id_, self.children)
-        self.assertEqual(sequence_me.get_id(), self.id_)
-
-    def test2get_child_elements(self):
-        """Test if get_child_elements returns None."""
-        sequence_me = SequenceModelElement(self.id_, self.children)
-        self.assertEqual(sequence_me.get_child_elements(), self.children)
-
-    def test3get_match_element_valid_match(self):
+    def test1get_match_element_valid_match(self):
         """Parse matching substring from MatchContext and check if the MatchContext was updated with all characters."""
         data = b"string0 string1 string2"
         match_context = DummyMatchContext(data)
@@ -41,7 +31,7 @@ class SequenceModelElementTest(TestBase):
         match_element = sequence_me.get_match_element(self.path, match_context)
         self.compare_match_results(data, match_element, match_context, self.id_, self.path, value, value, self.match_elements)
 
-    def test4get_match_element_no_match(self):
+    def test2get_match_element_no_match(self):
         """Parse not matching substring from MatchContext and check if the MatchContext was not changed."""
         data = b""
         match_context = DummyMatchContext(data)
@@ -67,7 +57,7 @@ class SequenceModelElementTest(TestBase):
         match_element = sequence_me.get_match_element(self.path, match_context)
         self.compare_no_match_results(data, match_element, match_context)
 
-    def test5element_id_input_validation(self):
+    def test3element_id_input_validation(self):
         """Check if element_id is validated."""
         self.assertRaises(ValueError, SequenceModelElement, "", self.children)
         self.assertRaises(TypeError, SequenceModelElement, None, self.children)
@@ -81,7 +71,7 @@ class SequenceModelElementTest(TestBase):
         self.assertRaises(TypeError, SequenceModelElement, (), self.children)
         self.assertRaises(TypeError, SequenceModelElement, set(), self.children)
 
-    def test6get_match_element_match_context_input_validation(self):
+    def test4get_match_element_match_context_input_validation(self):
         """Check if an exception is raised, when other classes than MatchContext are used in get_match_element."""
         model_element = SequenceModelElement(self.id_, self.children)
         data = b"string0 string1 string2"
