@@ -12,12 +12,9 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
-import os
-
 from aminer.input.InputInterfaces import AtomHandlerInterface
 from aminer.AminerConfig import CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX
 from aminer import AminerConfig
-from datetime import datetime
 
 
 class AllowlistViolationDetector(AtomHandlerInterface):
@@ -27,22 +24,19 @@ class AllowlistViolationDetector(AtomHandlerInterface):
     more than once, the allowlist rules may have match actions attached that set off an alarm by themselves.
     """
 
-    def __init__(self, aminer_config, allowlist_rules, anomaly_event_handlers, output_log_line=True):
+    def __init__(self, aminer_config, allowlist_rules, anomaly_event_handlers, output_logline=True):
         """
         Initialize the detector.
-        @param allowlist_rules list of rules executed in same way as inside Rules.OrMatchRule.
+        @param allowlist_rules list of rules executed until the first rule matches.
         """
-        self.allowlist_rules = allowlist_rules
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
-        self.persistence_id = None
+        super().__init__(aminer_config=aminer_config, anomaly_event_handlers=anomaly_event_handlers, output_logline=output_logline,
+                         allowlist_rules=allowlist_rules)
 
     def receive_atom(self, log_atom):
         """
-        Receive on parsed atom and the information about the parser match.
+        Receive a parsed atom and the information about the parser match.
         @param log_atom atom with parsed data to check
-        @return True when log_atom is allowlisted, False otherwise.
+        @return a boolean value if the log atom matches one of the rules.
         """
         self.log_total += 1
         event_data = {}
@@ -56,29 +50,10 @@ class AllowlistViolationDetector(AtomHandlerInterface):
         except UnicodeError:
             data = repr(log_atom.raw_data)
         analysis_component = {'AffectedLogAtomPaths': list(log_atom.parser_match.get_match_dictionary()), 'AffectedLogAtomValues': [data]}
-        if self.output_log_line:
-            match_paths_values = {}
-            for match_path, match_element in log_atom.parser_match.get_match_dictionary().items():
-                match_value = match_element.match_object
-                if isinstance(match_value, tuple):
-                    tmp_list = []
-                    for val in match_value:
-                        if isinstance(val, datetime):
-                            tmp_list.append(datetime.timestamp(val))
-                        else:
-                            tmp_list.append(val)
-                    match_value = tmp_list
-                if isinstance(match_value, bytes):
-                    match_value = match_value.decode(AminerConfig.ENCODING)
-                match_paths_values[match_path] = match_value
-            analysis_component['ParsedLogAtom'] = match_paths_values
-            sorted_log_lines = [
-                log_atom.parser_match.match_element.annotate_match('') + os.linesep + original_log_line_prefix + data]
-        else:
-            sorted_log_lines = [original_log_line_prefix + data]
+        sorted_log_lines = [original_log_line_prefix + data]
         event_data['AnalysisComponent'] = analysis_component
         for listener in self.anomaly_event_handlers:
-            listener.receive_event('Analysis.%s' % self.__class__.__name__, 'No allowlisting for current atom', sorted_log_lines,
+            listener.receive_event(f'Analysis.{self.__class__.__name__}', 'No allowlisting for current atom', sorted_log_lines,
                                    event_data, log_atom, self)
         return False
 
