@@ -12,8 +12,6 @@ this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-import os
-
 from aminer.input.InputInterfaces import AtomHandlerInterface
 from aminer.AminerConfig import CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX
 from aminer import AminerConfig
@@ -22,13 +20,22 @@ from aminer import AminerConfig
 class MatchFilter(AtomHandlerInterface):
     """This class creates events for specified paths and values."""
 
-    def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, target_value_list=None, output_log_line=True):
-        """Initialize the detector."""
-        self.target_path_list = target_path_list
-        self.target_value_list = target_value_list
-        self.anomaly_event_handlers = anomaly_event_handlers
-        self.aminer_config = aminer_config
-        self.output_log_line = output_log_line
+    def __init__(self, aminer_config, target_path_list, anomaly_event_handlers, target_value_list=None, output_logline=True):
+        """
+        Initialize the detector.
+        @param aminer_config configuration from analysis_context.
+        @param target_path_list parser paths of values to be analyzed. Multiple paths mean that values are analyzed by their combined
+               occurrences. When no paths are specified, the events given by the full path list are analyzed.
+        @param anomaly_event_handlers for handling events, e.g., print events to stdout.
+        @param target_value_list if not None, only match log atom if the match value is contained in the list.
+        @param output_logline specifies whether the full parsed log atom should be provided in the output.
+        """
+        # avoid "defined outside init" issue
+        self.next_persist_time, self.log_success, self.log_total = [None]*3
+        super().__init__(
+            aminer_config=aminer_config, target_path_list=target_path_list, anomaly_event_handlers=anomaly_event_handlers,
+            target_value_list=target_value_list, output_logline=output_logline
+        )
         self.persistence_id = 'Not persisted'
 
     def receive_atom(self, log_atom):
@@ -57,25 +64,9 @@ class MatchFilter(AtomHandlerInterface):
                 data = repr(log_atom.raw_data)
             original_log_line_prefix = self.aminer_config.config_properties.get(CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX)
             analysis_component = {'AffectedLogAtomPaths': [target_path], 'AffectedLogAtomValues': [str(affected_log_atom_values)]}
-            if self.output_log_line:
-                match_paths_values = {}
-                for match_path, match in match_dict.items():
-                    matches = []
-                    if isinstance(match, list):
-                        matches = match
-                    else:
-                        matches.append(match)
-                    for match_element in matches:
-                        match_value = match_element.match_object
-                        if isinstance(match_value, bytes):
-                            match_value = match_value.decode(AminerConfig.ENCODING)
-                        match_paths_values[match_path] = match_value
-                analysis_component['ParsedLogAtom'] = match_paths_values
-                sorted_log_lines = [log_atom.parser_match.match_element.annotate_match('') + os.linesep + original_log_line_prefix + data]
-            else:
-                sorted_log_lines = [original_log_line_prefix + data]
+            sorted_log_lines = [original_log_line_prefix + data]
             event_data = {'AnalysisComponent': analysis_component}
             for listener in self.anomaly_event_handlers:
-                listener.receive_event('Analysis.%s' % self.__class__.__name__, 'Log Atom Filtered',
-                                       sorted_log_lines, event_data, log_atom, self)
+                listener.receive_event(
+                    f'Analysis.{self.__class__.__name__}', 'Log Atom Filtered', sorted_log_lines, event_data, log_atom, self)
             self.log_success += 1
