@@ -88,8 +88,8 @@ class MatchRule(metaclass=abc.ABCMeta):
     def log_statistics(self, rule_id):
         """Log statistics of an MatchRule. Override this method for more sophisticated statistics output of the MatchRule."""
         if AminerConfig.STAT_LEVEL > 0:
-            logging.getLogger(STAT_LOG_NAME).info(f"Rule '{rule_id}' processed {self.log_success} out of {self.log_total} log atoms"
-                                                  f" successfully in the last 60 minutes.")
+            logging.getLogger(STAT_LOG_NAME).info("Rule '%s' processed %d out of %d log atoms successfully in the last 60 minutes.",
+                                                  rule_id, self.log_success, self.log_total)
         self.log_success = 0
         self.log_total = 0
         if hasattr(self, 'sub_rules'):
@@ -403,7 +403,7 @@ class StringRegexMatchRule(MatchRule):
 
     def match(self, log_atom):
         """Check if this rule matches. On match an optional match_action could be triggered."""
-        self. log_total += 1
+        self.log_total += 1
         # Use the class object as marker for nonexisting entries
         test_value = log_atom.parser_match.get_match_dictionary().get(self.target_path, None)
         if (test_value is None) or (self.match_regex.match(test_value.match_string) is None):
