@@ -26,13 +26,21 @@ class TimestampsUnsortedDetector(AtomHandlerInterface):
     This is useful mostly to detect algorithm malfunction or configuration errors, e.g. invalid timezone configuration.
     """
 
-    def __init__(self, aminer_config, anomaly_event_handlers, exit_on_error_flag=False, output_log_line=True):
-        """Initialize the detector."""
-        self.anomaly_event_handlers = anomaly_event_handlers
+    def __init__(self, aminer_config, anomaly_event_handlers, exit_on_error_flag=False, output_logline=True):
+        """
+        Initialize the detector.
+        @param aminer_config configuration from analysis_context.
+        @param anomaly_event_handlers for handling events, e.g., print events to stdout.
+        @param exit_on_error_flag exit the aminer forcefully if a log atom with a wrong timestamp is found.
+        @param output_logline specifies whether the full parsed log atom should be provided in the output.
+        """
+        # avoid "defined outside init" issue
+        self.log_success, self.log_total = [None]*2
+        super().__init__(
+            aminer_config=aminer_config, anomaly_event_handlers=anomaly_event_handlers, exit_on_error_flag=exit_on_error_flag,
+            output_logline=output_logline
+        )
         self.last_timestamp = 0
-        self.exit_on_error_flag = exit_on_error_flag
-        self.output_log_line = output_log_line
-        self.aminer_config = aminer_config
 
     def receive_atom(self, log_atom):
         """
@@ -50,17 +58,18 @@ class TimestampsUnsortedDetector(AtomHandlerInterface):
             except UnicodeError:
                 data = repr(log_atom.raw_data)
             original_log_line_prefix = self.aminer_config.config_properties.get(CONFIG_KEY_LOG_LINE_PREFIX, DEFAULT_LOG_LINE_PREFIX)
-            if self.output_log_line:
+            if self.output_logline:
                 sorted_log_lines = [log_atom.parser_match.match_element.annotate_match('') + os.linesep + original_log_line_prefix + data]
             else:
                 sorted_log_lines = [original_log_line_prefix + data]
             analysis_component = {'LastTimestamp': self.last_timestamp}
             event_data = {'AnalysisComponent': analysis_component}
             for listener in self.anomaly_event_handlers:
-                listener.receive_event('Analysis.%s' % self.__class__.__name__, 'Timestamp %s below %s' % (
-                    datetime.fromtimestamp(log_atom.get_timestamp()).strftime("%Y-%m-%d %H:%M:%S"),
-                    datetime.fromtimestamp(self.last_timestamp).strftime("%Y-%m-%d %H:%M:%S")), sorted_log_lines, event_data,
-                      log_atom, self)
+                listener.receive_event(
+                    f'Analysis.{self.__class__.__name__}',
+                    f"Timestamp {datetime.fromtimestamp(log_atom.get_timestamp()).strftime('%Y-%m-%d %H:%M:%S')} below "
+                    f"{datetime.fromtimestamp(self.last_timestamp).strftime('%Y-%m-%d %H:%M:%S')}", sorted_log_lines, event_data,
+                    log_atom, self)
             if self.exit_on_error_flag:
                 import sys
                 sys.exit(1)
