@@ -18,15 +18,28 @@ from aminer import AminerConfig
 class EventData:
     """This class is used to create a string for different event handlers."""
 
-    def __init__(self, event_type, event_message, sorted_log_lines, event_data, log_atom, event_source, analysis_context):
+    def __init__(self, event_type, event_message, sorted_loglines, event_data, log_atom, event_source, analysis_context):
+        """
+        Receive information about a detected event.
+        @param event_type is a string with the event type class this event belongs to. This information can be used to interpret
+               type-specific event_data objects. Together with the eventMessage and sorted_loglines, this can be used to create generic log
+               messages.
+        @param event_message the first output line of the event.
+        @param sorted_loglines sorted list of log lines that were considered when generating the event, as far as available to the time
+               of the event. The list has to contain at least one line.
+        @param event_data type-specific event data object, should not be used unless listener really knows about the event_type.
+        @param log_atom the log atom which produced the event.
+        @param event_source reference to detector generating the event.
+        @param analysis_context the analysis context used to get the component.
+        """
         self.event_type = event_type
         self.event_message = event_message
-        self.sorted_log_lines = sorted_log_lines
+        self.sorted_log_lines = sorted_loglines
         self.event_data = event_data
         self.event_source = event_source
         self.analysis_context = analysis_context
         if analysis_context is not None:
-            self.description = '"%s"' % analysis_context.get_name_by_component(event_source)
+            self.description = f'"{analysis_context.get_name_by_component(event_source)}"'
         else:
             self.description = ""
         if log_atom is None:
@@ -42,11 +55,11 @@ class EventData:
                 if self.log_atom.get_timestamp() is None:
                     import time
                     self.log_atom.set_timestamp(time.time())
-                message += "%s " % datetime.fromtimestamp(self.log_atom.get_timestamp()).strftime("%Y-%m-%d %H:%M:%S")
-                message += "%s\n" % self.event_message
-                message += "%s: %s (%d lines)\n" % (self.event_source.__class__.__name__, self.description, len(self.sorted_log_lines))
+                message += f"{datetime.fromtimestamp(self.log_atom.get_timestamp()).strftime('%Y-%m-%d %H:%M:%S')} "
+                message += f"{self.event_message}\n"
+                message += f"{self.event_source.__class__.__name__}: {self.description} ({len(self.sorted_log_lines)} lines)\n"
             else:
-                message += "%s (%d lines)\n" % (self.event_message, len(self.sorted_log_lines))
+                message += f"{self.event_message} ({len(self.sorted_log_lines)} lines)\n"
         else:
             indent = ""
         for line in self.sorted_log_lines:
