@@ -22,14 +22,31 @@ class KafkaEventHandler(EventHandlerInterface):
     """This class implements an event record listener, that will forward Json-objects to a Kafka queue."""
 
     def __init__(self, analysis_context, topic, options):
+        """
+        Initialize the event handler.
+        @param analysis_context the analysis context used to get the component.
+        @param topic the Kafka topic to which the data is sent.
+        @param options Kafka specific options.
+        """
         self.analysis_context = analysis_context
         self.options = options
         self.topic = topic
         self.producer = None
         self.kafka_imported = False
 
-    def receive_event(self, _event_type, _event_message, _sorted_log_lines, event_data, _log_atom, event_source):
-        """Receive information about a detected event in json format."""
+    def receive_event(self, _event_type, _event_message, _sorted_loglines, event_data, _log_atom, event_source):
+        """
+        Receive information about a detected event in json format.
+        @param _event_type is a string with the event type class this event belongs to. This information can be used to interpret
+               type-specific event_data objects. Together with the eventMessage and sorted_loglines, this can be used to create generic log
+               messages.
+        @param _event_message the first output line of the event.
+        @param _sorted_loglines sorted list of log lines that were considered when generating the event, as far as available to the time
+               of the event. The list has to contain at least one line.
+        @param event_data type-specific event data object, should not be used unless listener really knows about the event_type.
+        @param _log_atom the log atom which produced the event.
+        @param event_source reference to detector generating the event.
+        """
         if hasattr(event_source, 'output_event_handlers') and event_source.output_event_handlers is not None and self not in \
                 event_source.output_event_handlers:
             return True
