@@ -11,41 +11,21 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
 
 class AnyByteDataModelElement(ModelElementInterface):
-    """This class matches any byte but at least one. Thus a match will always span the complete data from beginning to end."""
-
-    def __init__(self, element_id: str):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
-        """
-        Get all possible child model elements of this element.
-        @return None as there are no children of this element.
-        """
-        return None
+    """This class matches any byte but at least one. Thus, a match will always span the complete data from beginning to end."""
 
     def get_match_element(self, path: str, match_context):
-        """Just return a match including all data from the context."""
+        """
+        Just return a match including all data from the context.
+        @param path to be printed in the MatchElement.
+        @param match_context the match_context to be analyzed.
+        """
         match_data = match_context.match_data
         if not match_data:
             return None
         match_context.update(match_data)
-        return MatchElement("%s/%s" % (path, self.element_id), match_data, match_data, None)
+        return MatchElement(f"{path}/{self.element_id}", match_data, match_data, None)
