@@ -11,9 +11,6 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
-
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 from aminer.parsing.MatchElement import MatchElement
 
@@ -38,100 +35,48 @@ class DecimalFloatValueModelElement(ModelElementInterface):
 
     def __init__(self, element_id: str, value_sign_type: str = SIGN_TYPE_NONE, value_pad_type: str = PAD_TYPE_NONE,
                  exponent_type: str = EXP_TYPE_NONE):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-        if not isinstance(value_sign_type, str):
-            msg = 'value_sign_type must be of type string.' % value_sign_type
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if value_sign_type == DecimalFloatValueModelElement.SIGN_TYPE_NONE:
-            self.start_characters = b"0123456789"
-        elif value_sign_type == DecimalFloatValueModelElement.SIGN_TYPE_OPTIONAL:
-            self.start_characters = b"-0123456789"
-        elif value_sign_type == DecimalFloatValueModelElement.SIGN_TYPE_MANDATORY:
-            self.start_characters = b"+-"
-        else:
-            msg = 'Invalid value_sign_type "%s"' % value_sign_type
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-
-        self.pad_characters = b""
-        if not isinstance(value_pad_type, str):
-            msg = 'value_pad_type must be of type string.' % value_sign_type
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if value_pad_type == DecimalFloatValueModelElement.PAD_TYPE_NONE:
-            pass
-        elif value_pad_type == DecimalFloatValueModelElement.PAD_TYPE_ZERO:
-            self.pad_characters = b"0"
-        elif value_pad_type == DecimalFloatValueModelElement.PAD_TYPE_BLANK:
-            self.pad_characters = b" "
-        else:
-            msg = 'Invalid value_pad_type "%s"' % value_sign_type
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.value_pad_type = value_pad_type
-
-        if not isinstance(exponent_type, str):
-            msg = 'exponent_type must be of type string.' % value_sign_type
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if exponent_type not in [DecimalFloatValueModelElement.EXP_TYPE_NONE, DecimalFloatValueModelElement.EXP_TYPE_OPTIONAL,
-                                 DecimalFloatValueModelElement.EXP_TYPE_MANDATORY]:
-            msg = 'Invalid exponent_type "%s"' % exponent_type
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.exponent_type = exponent_type
-
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
         """
-        Get all possible child model elements of this element.
-        @return empty list as there are no children of this element.
+        Initialize the ModelElement.
+        @param element_id an identifier for the ModelElement which is shown in the path.
+        @param value_sign_type defines the possible start characters in the value. With the SIGN_TYPE_NONE only digits are allowed,
+               with SIGN_TYPE_OPTIONAL digits and a minus sign are allowed and with SIGN_TYPE_MANDATORY the value must start with + or -.
+        @param value_pad_type defines the padding values which can prefix the numerical value. With PAD_TYPE_NONE no padding is allowed,
+               PAD_TYPE_ZERO allows zeros before the value and PAD_TYPE_BLANK allows spaces before the value.
+        @param exponent_type defines the allowed types of exponential values. With EXP_TYPE_NONE no exponential values are allowed,
+               EXP_TYPE_OPTIONAL allows exponential values and with EXP_TYPE_MANDATORY every value must contain exponential values.
         """
-        return None
+        super().__init__(element_id, value_sign_type=value_sign_type, value_pad_type=value_pad_type, exponent_type=exponent_type)
+        self.digits = set(b"0123456789")
 
     def get_match_element(self, path: str, match_context):
         """
         Find the maximum number of bytes forming a decimal number according to the parameters specified.
+        @param path to be printed in the MatchElement.
+        @param match_context the match_context to be analyzed.
         @return a match when at least one byte being a digit was found
         """
         data = match_context.match_data
 
-        allowed_characters = self.start_characters
-        if not data or (data[0] not in allowed_characters):
+        if not data or (data[0] not in self.start_characters):
             return None
         match_len = 1
 
         if self.pad_characters == b"" and data.startswith(b"0") and not data.startswith(b"0.") and len(data) > 1 and \
-                data[1] in b"0123456789":
+                data[1] in self.digits:
             return None
 
-        allowed_characters = self.pad_characters
         for test_byte in data[match_len:]:
-            if test_byte not in allowed_characters:
+            if test_byte not in self.pad_characters:
                 break
             match_len += 1
         num_start_pos = match_len
-        allowed_characters = b"0123456789"
         for test_byte in data[match_len:]:
-            if test_byte not in allowed_characters:
+            if test_byte not in self.digits:
                 break
             match_len += 1
 
         if match_len == 1:  # skipcq: PTC-W0048
-            if data[0] not in b"0123456789":
+            if data[0] not in self.digits:
                 return None
         elif num_start_pos == match_len and match_len == 1:  # only return None if match_len is 1 to allow 00 with zero padding.
             return None
@@ -141,7 +86,7 @@ class DecimalFloatValueModelElement(ModelElementInterface):
             match_len += 1
             post_point_start = match_len
             for test_byte in data[match_len:]:
-                if test_byte not in b"0123456789":
+                if test_byte not in self.digits:
                     break
                 match_len += 1
             if match_len == post_point_start - 1:
@@ -156,12 +101,14 @@ class DecimalFloatValueModelElement(ModelElementInterface):
                 match_len += 1
             exp_number_start = match_len
             for test_byte in data[match_len:]:
-                if test_byte not in b"0123456789":
+                if test_byte not in self.digits:
                     break
                 match_len += 1
             if match_len == exp_number_start:
                 # No exponent number found.
                 return None
+        elif self.exponent_type == DecimalFloatValueModelElement.EXP_TYPE_MANDATORY:
+            return None
 
         match_string = data[:match_len]
         if self.pad_characters == b" " and match_string[0] in b"+-":
@@ -171,4 +118,4 @@ class DecimalFloatValueModelElement(ModelElementInterface):
         else:
             match_value = float(match_string)
         match_context.update(match_string)
-        return MatchElement("%s/%s" % (path, self.element_id), match_string, match_value, None)
+        return MatchElement(f"{path}/{self.element_id}", match_string, match_value, None)
