@@ -11,8 +11,6 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
 
@@ -20,42 +18,16 @@ class FirstMatchModelElement(ModelElementInterface):
     """This class defines a model element to return the match from the the first matching child model within a given list."""
 
     def __init__(self, element_id: str, children: list):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-
-        if not isinstance(children, list):
-            msg = "children has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(children) < 1:
-            msg = "children must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        for child in children:
-            if not isinstance(child, ModelElementInterface):
-                msg = "all children have to be of the type ModelElementInterface."
-                logging.getLogger(DEBUG_LOG_NAME).error(msg)
-                raise TypeError(msg)
-        self.children = children
-
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):
-        """Get all possible child model elements of this element."""
-        return self.children
+        """
+        Initialize the ModelElement.
+        @param element_id an identifier for the ModelElement which is shown in the path.
+        @param children a list of child elements to be iterated through.
+        """
+        super().__init__(element_id, children=children)
 
     def get_match_element(self, path: str, match_context):
         """@return None when there is no match, MatchElement otherwise."""
-        current_path = "%s/%s" % (path, self.element_id)
+        current_path = f"{path}/{self.element_id}"
 
         match_data = match_context.match_data
         for child_element in self.children:
