@@ -12,8 +12,6 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
 
-import logging
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
@@ -25,39 +23,16 @@ class FixedDataModelElement(ModelElementInterface):
     """
 
     def __init__(self, element_id: str, fixed_data: bytes):
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        if not isinstance(fixed_data, bytes):
-            msg = "fixed_data has to be of the type byte string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(fixed_data) < 1:
-            msg = "fixed_data must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
-        self.fixed_data = fixed_data
-
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
         """
-        Get all possible child model elements of this element.
-        @return None as there are no children of this element.
+        Initialize the ModelElement.
+        @param element_id an identifier for the ModelElement which is shown in the path.
+        @param fixed_data a non-escaped delimiter string to search for.
         """
-        return None
+        super().__init__(element_id, fixed_data=fixed_data)
 
     def get_match_element(self, path: str, match_context):
         """@return None when there is no match, MatchElement otherwise."""
         if not match_context.match_data.startswith(self.fixed_data):
             return None
         match_context.update(self.fixed_data)
-        return MatchElement("%s/%s" % (path, self.element_id), self.fixed_data, self.fixed_data, None)
+        return MatchElement(f"{path}/{self.element_id}", self.fixed_data, self.fixed_data, None)
