@@ -11,9 +11,7 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 """
-import logging
 import re
-from aminer.AminerConfig import DEBUG_LOG_NAME
 from aminer.parsing.MatchElement import MatchElement
 from aminer.parsing.ModelElementInterface import ModelElementInterface
 
@@ -22,21 +20,13 @@ class IpAddressDataModelElement(ModelElementInterface):
     """This class defines a model element that matches an IP address."""
 
     def __init__(self, element_id: str, ipv6: bool = False):
-        """Create an element to match IP addresses."""
-        if not isinstance(element_id, str):
-            msg = "element_id has to be of the type string."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
-        if len(element_id) < 1:
-            msg = "element_id must not be empty."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise ValueError(msg)
-        self.element_id = element_id
+        """
+        Create an element to match IP addresses.
+        @param element_id an identifier for the ModelElement which is shown in the path.
+        @param ipv6 if True, IPv6 addresses are parsed, IPv4 addresses are parsed otherwise.
+        """
+        super().__init__(element_id, ipv6=ipv6)
 
-        if not isinstance(ipv6, bool):
-            msg = "ipv6 has to be of the type bool."
-            logging.getLogger(DEBUG_LOG_NAME).error(msg)
-            raise TypeError(msg)
         if not ipv6:
             # self.regex = re.compile(br"((2[0-4][0-9]|1[0-9][0-9]|25[0-5]|[1-9]?[0-9])\.){3}(2[0-4][0-9]|1[0-9][0-9]|25[0-5]|[1-9]?[0-9])")
             # use a simpler regex to improve the performance.
@@ -55,17 +45,6 @@ class IpAddressDataModelElement(ModelElementInterface):
                 br")))(%.+)?")
             self.extract = extract_ipv6_address
 
-    def get_id(self):
-        """Get the element ID."""
-        return self.element_id
-
-    def get_child_elements(self):  # skipcq: PYL-R0201
-        """
-        Get all possible child model elements of this element.
-        @return None as there are no children of this element.
-        """
-        return None
-
     def get_match_element(self, path: str, match_context):
         """
         Read an IP address at the current data position. When found, the match_object will be.
@@ -86,7 +65,7 @@ class IpAddressDataModelElement(ModelElementInterface):
             return None
         match_string = data[:match_len]
         match_context.update(match_string)
-        return MatchElement("%s/%s" % (path, self.element_id), match_string, extracted_address, None)
+        return MatchElement(f"{path}/{self.element_id}", match_string, extracted_address, None)
 
 
 def extract_ipv4_address(data: bytes, match_len: int):
